# https://gitlab.gnome.org/GNOME/pygobject/issues/253#note_317277
# We don't need to ever pass --no-undefined to Meson because it is enabled by
# default (see: b_lundef option) and is automatically disabled on build targets
# (such as modules) that need it to not be set.

# One issue with this package is that it python3-gobject can pull in a lot
# of extra packages.  There are two ways other distributions deal with this
# Fedora splits out cairo into a separate package but does not do typelib
# dependence.
#
# Opensuse splits out python3-gobject,python3-gobject-gdk,python3-gobject-cairo
#
# We split up gobject into base and the general package but more of the
# package is placed in the main package.  Also splitting out cairo doesn't
# help much because gtk will pull in cairo anyway.

%define _disable_ld_no_undefined 1

%define oname   pygobject

%global __provides_exclude_from ^(%{python3_sitelib}|%{python3_sitearch})/(pygtkcompat|gi/pygtkcompat.py|gi/_gobject/__init__.py|gi/module.py|gi/__init__.py|gi/overrides/GIMarshallingTests.py)
%global __requires_exclude_from ^(%{python3_sitelib}|%{python3_sitearch})/(pygtkcompat|gi/pygtkcompat.py|gi/_gobject/__init__.py|gi/module.py|gi/__init__.py|gi/overrides/GIMarshallingTests.py)

%global __requires_exclude typelib\\(%%namespaces

%define url_ver %{lua: ver = rpm.expand("%{version}"); majmin, count1 = string.gsub(ver, "^([0123456789]+%.[0123456789]+).*", "%1", 1); if count1 == 0 then print(ver); return; end; maj, count2 = string.gsub(majmin, "^([0123456789]+).*", "%1", 1); if count2 == 0 then print(majmin) elseif tonumber(majmin) < 40 then print(majmin) else print(maj) end}

Summary:	Python bindings for GObject Introspection
Name:		python-gobject
Version:	3.44.1
Release:	%mkrel 1
License:	LGPLv2+ and MIT
Group:		Development/Python
Url:		https://www.gnome.org/
Source0:	https://download.gnome.org/sources/%{oname}/%{url_ver}/%{oname}-%{version}.tar.xz
BuildRequires:	gnome-common
BuildRequires:	gtk-doc
BuildRequires:	meson
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(py3cairo)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python-srpm-macros
Obsoletes:	python-gobject3 < 3.36.1-2

%description
The %{name} package provides a convenient wrapper for the GObject library
for use in Python programs.

%package -n python3-gobject-devel
Group:		Development/C
Summary:	Python-gobject development files
Requires:	python3-gobject = %{version}-%{release}
Provides:	python3-gobject3-devel = %{version}-%{release}
Provides:	python-gobject3-devel = %{version}-%{release}
Obsoletes:	python-gobject3-devel < 3.36.1-2

%description -n python3-gobject-devel
This contains the python-gobject development files, including C
header, pkg-config file.

%package     -n python3-gobject-base
Summary:        Python 3 bindings for GObject Introspection base package
Requires:       gobject-introspection
Obsoletes:	python3-gobject <= 3.38.0-2

%description -n python3-gobject-base
This package provides the non-cairo specific bits of the GObject Introspection
library.

%package -n python3-gobject
Summary:	Python 3 bindings for GObject Introspection
Group:		Development/Python
Requires:	python3-cairo >= 1.10.0-15
Requires:	python3-gobject-base = %{version}-%{release}
Provides:	python3-gi = %{version}-%{release}
Provides:	python3-gobject3 = %{version}-%{release}
Provides:	python3-gobject3%{_isa} = %{version}-%{release}
Obsoletes:	python3-gobject3 < 3.36.1-2

%description -n python3-gobject
This package provides a convenient wrapper for the GObject library and other
libraries that are compatible with GObject Introspection, for use with Python 3
programs.

%prep
%setup -qn %{oname}-%{version}

# drop bundled egg-info
rm -rf *.egg-info/

%build
%meson -Dpython=%{__python3}
%meson_build

%install
%meson_install

%files -n python3-gobject-devel
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%files -n python3-gobject
%{python3_sitearch}/gi/_gi_cairo*.so
%{python3_sitearch}/gi/_gtktemplate.py
%{python3_sitearch}/gi/pygtkcompat.py
%{python3_sitelib}/gi/overrides/Gdk.*
%{python3_sitelib}/gi/overrides/GdkPixbuf.py
%{python3_sitelib}/gi/overrides/Gtk.*
%{python3_sitelib}/gi/overrides/keysyms.*
%{python3_sitelib}/gi/overrides/Pango.*
%{python3_sitelib}/gi/overrides/__pycache__/Gdk*
%{python3_sitelib}/gi/overrides/__pycache__/Gtk.*
%{python3_sitelib}/gi/overrides/__pycache__/keysyms.*
%{python3_sitelib}/gi/overrides/__pycache__/Pango.*
%{python3_sitelib}/pygtkcompat/
%{python3_sitearch}/gi/__pycache__/pygtkcompat.*

%files -n python3-gobject-base
%{python3_sitelib}/gi/
%{python3_sitearch}/gi/
%{python3_sitearch}/PyGObject-%{version}.egg-info
%exclude %{python3_sitearch}/gi/pygtkcompat.py
%exclude %{python3_sitearch}/gi/_gi_cairo*.so
%exclude %{python3_sitearch}/gi/__pycache__/pygtkcompat.*
%exclude %{python3_sitearch}/gi/_gtktemplate.py
%exclude %{python3_sitelib}/gi/overrides/Gdk.*
%exclude %{python3_sitelib}/gi/overrides/GdkPixbuf.py
%exclude %{python3_sitelib}/gi/overrides/Gtk.*
%exclude %{python3_sitelib}/gi/overrides/keysyms.*
%exclude %{python3_sitelib}/gi/overrides/Pango.*
%exclude %{python3_sitelib}/pygtkcompat/
%exclude %{python3_sitelib}/gi/overrides/__pycache__/Gdk*
%exclude %{python3_sitelib}/gi/overrides/__pycache__/Gtk.*
%exclude %{python3_sitelib}/gi/overrides/__pycache__/keysyms.*
%exclude %{python3_sitelib}/gi/overrides/__pycache__/Pango.*



%changelog
* Thu Apr 27 2023 neoclust <neoclust> 3.44.1-1.mga9
+ Revision: 1955114
- New version 3.44.1

* Sat Apr 22 2023 tmb <tmb> 3.44.0-1.mga9
+ Revision: 1954134
- update to 3.44.0
+ daviddavid <daviddavid>
- new version 3.43.1

* Sat Jul 16 2022 ovitters <ovitters> 3.42.2-1.mga9
+ Revision: 1869207
- new version 3.42.2

* Sun Apr 17 2022 ovitters <ovitters> 3.42.1-1.mga9
+ Revision: 1850971
- new version 3.42.1

* Thu Mar 31 2022 umeabot <umeabot> 3.42.0-3.mga9
+ Revision: 1835733
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 3.42.0-2.mga9
+ Revision: 1772304
- rebuild for python3.10

* Mon Jan 10 2022 tv <tv> 3.42.0-1.mga9
+ Revision: 1767442
- 3.42.0

* Thu Aug 05 2021 luigiwalser <luigiwalser> 3.40.1-2.mga9
+ Revision: 1739666
- rebuild for libffi

* Tue Mar 30 2021 ovitters <ovitters> 3.40.1-1.mga9
+ Revision: 1711852
- new version 3.40.1

* Thu Mar 25 2021 ovitters <ovitters> 3.40.0-1.mga9
+ Revision: 1709889
- new version 3.40.0

* Sun Mar 14 2021 wally <wally> 3.38.0-6.mga9
+ Revision: 1702724
- rebuild for python 3.9

* Mon Dec 14 2020 joequant <joequant> 3.38.0-5.mga8
+ Revision: 1657303
- move gtk/gdk bits into python3-gobject (mga#27805)

* Fri Dec 11 2020 wally <wally> 3.38.0-4.mga8
+ Revision: 1655481
- revert requires exclude change from r1654227

* Wed Dec 09 2020 joequant <joequant> 3.38.0-3.mga8
+ Revision: 1654846
- add obsoletes to replace python3-gobject with python3-gobject-base

* Mon Dec 07 2020 joequant <joequant> 3.38.0-2.mga8
+ Revision: 1654227
- fix requires to exclude typelib and move cairo to separate deps

* Sun Sep 13 2020 ovitters <ovitters> 3.38.0-1.mga8
+ Revision: 1625734
- new version 3.38.0

* Fri Aug 21 2020 joequant <joequant> 3.36.1-6.mga8
+ Revision: 1617294
- fix deps

* Fri Aug 21 2020 joequant <joequant> 3.36.1-5.mga8
+ Revision: 1617159
- fix build

* Thu Jun 11 2020 joequant <joequant> 3.36.1-4.mga8
+ Revision: 1592279
- rebuild with new ffi

* Mon Jun 01 2020 daviddavid <daviddavid> 3.36.1-3.mga8
+ Revision: 1589432
- provides also python3-gobject3%%{_isa}

* Thu May 07 2020 wally <wally> 3.36.1-2.mga8
+ Revision: 1581569
- rename src.rpm as python-gobject
- update pkg names

* Thu May 07 2020 ovitters <ovitters> 3.36.1-1.mga8
+ Revision: 1581411
- new version 3.36.1
+ danf <danf>
- Switch URLs from http: to https:

* Mon Mar 09 2020 ovitters <ovitters> 3.36.0-1.mga8
+ Revision: 1555114
- new version 3.36.0

* Sun Feb 16 2020 umeabot <umeabot> 3.34.0-3.mga8
+ Revision: 1533444
- Mageia 8 Mass Rebuild

* Sat Sep 21 2019 wally <wally> 3.34.0-2.mga8
+ Revision: 1444489
- drop python2 support
+ ovitters <ovitters>
- new version 3.34.0

* Thu Sep 05 2019 tv <tv> 3.32.2-2.mga8
+ Revision: 1437462
- BR python-srpm-macros >= 3-8 for %%__python2 definition b/c iurt doesn't
  explicitely update pkgs from core/updates_testing, only fetch missing deps
- rebuild for python 3.8

* Tue Jul 02 2019 ovitters <ovitters> 3.32.2-1.mga8
+ Revision: 1417738
- new version 3.32.2

* Sat Apr 20 2019 ovitters <ovitters> 3.32.1-1.mga7
+ Revision: 1393835
- new version 3.32.1

* Thu Apr 18 2019 umeabot <umeabot> 3.32.0-2.mga7
+ Revision: 1392902
- Rebuild with meson 0.50.1

* Sun Mar 10 2019 ovitters <ovitters> 3.32.0-1.mga7
+ Revision: 1373623
- new version 3.32.0

* Sun Mar 10 2019 daviddavid <daviddavid> 3.31.4-1.mga7
+ Revision: 1373607
- new version 3.31.4

* Tue Feb 26 2019 daviddavid <daviddavid> 3.30.4-3.mga7
+ Revision: 1370207
- fix dangling link (mga#23519)

* Sat Jan 05 2019 wally <wally> 3.30.4-2.mga7
+ Revision: 1349488
- rebuild for python3.7

* Fri Nov 30 2018 ovitters <ovitters> 3.30.4-1.mga7
+ Revision: 1336954
- new version 3.30.4

* Tue Nov 27 2018 ovitters <ovitters> 3.30.3-1.mga7
+ Revision: 1335956
- new version 3.30.3

* Mon Nov 12 2018 ovitters <ovitters> 3.30.2-1.mga7
+ Revision: 1329679
- new version 3.30.2

* Sun Sep 16 2018 daviddavid <daviddavid> 3.30.1-1.mga7
+ Revision: 1259219
- new version 3.30.1

* Thu Sep 06 2018 daviddavid <daviddavid> 3.30.0-1.mga7
+ Revision: 1257563
- new version 3.30.0
- rename python-gi to python2-gi
- rename python-gi-cairo to python2-gi-cairo

* Thu Aug 30 2018 joequant <joequant> 3.29.3-1.mga7
+ Revision: 1255774
- update to 3.29.3

* Tue Aug 14 2018 tv <tv> 3.29.2-1.mga7
+ Revision: 1251453
- new release
- switch to meson

* Tue Mar 27 2018 ovitters <ovitters> 3.28.2-1.mga7
+ Revision: 1212958
- new version 3.28.2

* Sat Mar 17 2018 ovitters <ovitters> 3.28.1-1.mga7
+ Revision: 1210160
- new version 3.28.1

* Mon Mar 12 2018 ovitters <ovitters> 3.28.0-1.mga7
+ Revision: 1208428
- new version 3.28.0

* Thu Mar 01 2018 ovitters <ovitters> 3.27.5-1.mga7
+ Revision: 1205891
- new version 3.27.5

* Wed Feb 14 2018 ovitters <ovitters> 3.27.4-1.mga7
+ Revision: 1200930
- new version 3.27.4

* Sat Feb 10 2018 ovitters <ovitters> 3.27.3-1.mga7
+ Revision: 1200123
- new version 3.27.3

* Wed Feb 07 2018 ovitters <ovitters> 3.27.2-1.mga7
+ Revision: 1199605
- new version 3.27.2

* Sun Aug 13 2017 joequant <joequant> 3.24.1-4.mga7
+ Revision: 1140021
- rebuild for arm

* Thu Aug 03 2017 tv <tv> 3.24.1-3.mga7
+ Revision: 1134455
- rebuild for new python

* Thu Aug 03 2017 daviddavid <daviddavid> 3.24.1-2.mga7
+ Revision: 1134235
- provides python3-gi

* Mon Apr 10 2017 ovitters <ovitters> 3.24.1-1.mga7
+ Revision: 1096250
- new version 3.24.1

* Tue Mar 21 2017 ovitters <ovitters> 3.24.0-1.mga6
+ Revision: 1094026
- new version 3.24.0

* Sat Sep 24 2016 ovitters <ovitters> 3.22.0-1.mga6
+ Revision: 1055753
- new version 3.22.0

* Mon May 23 2016 joequant <joequant> 3.20.1-4.mga6
+ Revision: 1017899
- remove GIMarshallingTests requires

* Mon May 23 2016 joequant <joequant> 3.20.1-3.mga6
+ Revision: 1017879
- bump to build on arm

* Thu Apr 28 2016 tv <tv> 3.20.1-2.mga6
+ Revision: 1007106
- use new python macros

* Mon Apr 25 2016 ovitters <ovitters> 3.20.1-1.mga6
+ Revision: 1006030
- new version 3.20.1
+ tv <tv>
- do not package huge ChangeLog

* Tue Mar 22 2016 ovitters <ovitters> 3.20.0-1.mga6
+ Revision: 993890
- new version 3.20.0

* Wed Mar 16 2016 ovitters <ovitters> 3.19.92-1.mga6
+ Revision: 991837
- new version 3.19.92

* Wed Mar 02 2016 ovitters <ovitters> 3.19.91-1.mga6
+ Revision: 982670
- new version 3.19.91

* Sun Feb 21 2016 ovitters <ovitters> 3.19.90-1.mga6
+ Revision: 975036
- new version 3.19.90

* Sat Feb 13 2016 luigiwalser <luigiwalser> 3.19.2-2.mga6
+ Revision: 959436
- link with python lib to fix python3 build

* Mon Nov 23 2015 ovitters <ovitters> 3.19.2-1.mga6
+ Revision: 904997
- new version 3.19.2

* Sat Oct 24 2015 ovitters <ovitters> 3.18.2-1.mga6
+ Revision: 895008
- new version 3.18.2

* Sat Oct 24 2015 ovitters <ovitters> 3.18.1-1.mga6
+ Revision: 894980
- new version 3.18.1

* Wed Oct 07 2015 tv <tv> 3.18.0-3.mga6
+ Revision: 886696
- rebuild for python 3.5

* Fri Oct 02 2015 tv <tv> 3.18.0-2.mga6
+ Revision: 885743
- require fixed python3-cairo (mga#16845)

* Fri Sep 25 2015 tv <tv> 3.18.0-1.mga6
+ Revision: 883484
- new release

* Thu Aug 20 2015 ovitters <ovitters> 3.17.90-1.mga6
+ Revision: 866617
- new version 3.17.90

* Thu Jul 09 2015 ovitters <ovitters> 3.17.1-1.mga6
+ Revision: 853147
- new version 3.17.1

* Wed Oct 15 2014 umeabot <umeabot> 3.14.0-2.mga5
+ Revision: 742916
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 wally <wally> 3.14.0-1.mga5
+ Revision: 733830
- new version 3.14.0

* Sat Sep 27 2014 tv <tv> 3.13.92-3.mga5
+ Revision: 728610
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.13.92-2.mga5
+ Revision: 688058
- Mageia 5 Mass Rebuild
+ tv <tv>
- simplify
- auto convert _exclude_files_from_autoreq
- use %%global for req/prov exclude

* Tue Sep 16 2014 ovitters <ovitters> 3.13.92-1.mga5
+ Revision: 676967
- new version 3.13.92
+ tv <tv>
- autoconvert to new prov/req excludes

* Sun Sep 14 2014 ovitters <ovitters> 3.13.4-2.mga5
+ Revision: 675393
- remove unneeded patch which didn't apply
- devel subpackages should ensure gobject-introspection is installed for auto typelib buildrequires

* Tue Jun 24 2014 ovitters <ovitters> 3.13.3-1.mga5
+ Revision: 639213
- new version 3.13.3

* Sun Jun 01 2014 wally <wally> 3.12.2-1.mga5
+ Revision: 630305
- add patch to fix linking
+ pterjan <pterjan>
- 3.12.2
- Rebuild for new Python

* Tue Feb 18 2014 fwang <fwang> 3.11.90-2.mga5
+ Revision: 594175
- update filter

* Tue Feb 18 2014 fwang <fwang> 3.11.90-1.mga5
+ Revision: 594158
- update file list
+ ovitters <ovitters>
- new version 3.11.90

* Mon Nov 11 2013 ovitters <ovitters> 3.10.2-1.mga4
+ Revision: 550507
- new version 3.10.2

* Tue Oct 22 2013 umeabot <umeabot> 3.10.1-3.mga4
+ Revision: 543595
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.10.1-2.mga4
+ Revision: 498698
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Oct 14 2013 ovitters <ovitters> 3.10.1-1.mga4
+ Revision: 496953
- new version 3.10.1

* Wed Sep 25 2013 fwang <fwang> 3.10.0-2.mga4
+ Revision: 485887
- split our python3 libs

* Mon Sep 23 2013 ovitters <ovitters> 3.10.0-1.mga4
+ Revision: 484127
- new version 3.10.0

* Tue Sep 17 2013 fwang <fwang> 3.9.92-7.mga4
+ Revision: 480680
+ rebuild (emptylog)

* Tue Sep 17 2013 fwang <fwang> 3.9.92-6.mga4
+ Revision: 480664
- fix typo on splitter

* Tue Sep 17 2013 fwang <fwang> 3.9.92-5.mga4
+ Revision: 480656
- filter correct files

* Tue Sep 17 2013 fwang <fwang> 3.9.92-4.mga4
+ Revision: 480647
- only filter pygtkcompat

* Tue Sep 17 2013 fwang <fwang> 3.9.92-3.mga4
+ Revision: 480638
- mask more files

* Tue Sep 17 2013 fwang <fwang> 3.9.92-2.mga4
+ Revision: 480634
- update exclude file list

* Tue Sep 17 2013 ovitters <ovitters> 3.9.92-1.mga4
+ Revision: 480545
- new version 3.9.92

* Sun Sep 01 2013 tmb <tmb> 3.9.90-1.mga4
+ Revision: 473799
- update to 3.9.90

* Thu Aug 08 2013 wally <wally> 3.8.2-4.mga4
+ Revision: 464637
- rebuild with new rpm-mageia-setup

* Sat May 25 2013 ovitters <ovitters> 3.8.2-3.mga4
+ Revision: 427550
- really fix requires

* Sat May 25 2013 ovitters <ovitters> 3.8.2-2.mga4
+ Revision: 427540
- fix work autorequire

* Sat May 25 2013 ovitters <ovitters> 3.8.2-1.mga4
+ Revision: 427426
- update file list
- new version 3.8.2

* Sun Jan 13 2013 umeabot <umeabot> 3.4.2-2.mga3
+ Revision: 378935
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 13 2012 fwang <fwang> 3.4.2-1.mga3
+ Revision: 317339
- update file list
- new version 3.4.2
+ ovitters <ovitters>
- new version 3.4.1.1

* Mon Oct 15 2012 fwang <fwang> 3.4.1-1.mga3
+ Revision: 306020
- update file list
- update file list
+ ovitters <ovitters>
- new version 3.4.1

* Sat Sep 29 2012 fwang <fwang> 3.4.0-2.mga3
+ Revision: 300330
- rebuild for new py3.3

* Mon Sep 24 2012 fwang <fwang> 3.4.0-1.mga3
+ Revision: 297069
- new version 3.4.0

* Tue Sep 18 2012 fwang <fwang> 3.3.92-1.mga3
+ Revision: 295730
- new version 3.3.92

* Mon Aug 06 2012 fwang <fwang> 3.3.5-1.mga3
+ Revision: 279380
- new version 3.3.5

* Fri Jul 13 2012 fwang <fwang> 3.3.3.1-5.mga3
+ Revision: 270611
- update file list to fix file conflicts

* Fri Jul 13 2012 fwang <fwang> 3.3.3.1-4.mga3
+ Revision: 270525
- do not requires python-gi

* Fri Jul 13 2012 fwang <fwang> 3.3.3.1-3.mga3
+ Revision: 270517
- update file list
- update file list

* Fri Jul 13 2012 kamil <kamil> 3.3.3.1-2.mga3
+ Revision: 270476
- add python3 subpackage

* Tue Jul 03 2012 kamil <kamil> 3.3.3.1-1.mga3
+ Revision: 267105
- new version 3.3.3.1
- remove P0 (not used anymore)
- new P0 pygobject-3.3.3.1-fix-segfault-with-class-interface-mismatch.patch from Fedora

* Mon May 14 2012 ovitters <ovitters> 3.2.2-1.mga3
+ Revision: 235674
- new version 3.2.2
- new version 3.2.1

* Sat Apr 07 2012 fwang <fwang> 3.2.0-3.mga2
+ Revision: 229564
- fix typo on filter

* Sat Apr 07 2012 fwang <fwang> 3.2.0-2.mga2
+ Revision: 229556
- do not push autoreq from pygtkcompat module

* Mon Mar 26 2012 ovitters <ovitters> 3.2.0-1.mga2
+ Revision: 226573
- new version 3.2.0

* Fri Mar 23 2012 anssi <anssi> 3.1.93-2.mga2
+ Revision: 225856
- drop patch which adapted to API change made in upstream GTK+ bug
  #657385, it has now been reverted in GTK+ 3.3.20

* Thu Mar 22 2012 ovitters <ovitters> 3.1.93-1.mga2
+ Revision: 225662
- new version 3.1.93

* Mon Mar 19 2012 ovitters <ovitters> 3.1.92-1.mga2
+ Revision: 224400
- new version 3.1.92

* Wed Mar 07 2012 anssi <anssi> 3.1.1-2.mga2
+ Revision: 221179
- adapt for an API change made in gnome bug #657385 (this change might
  get reverted later, though; adapt-for-gnome657385.patch)

* Tue Feb 21 2012 fwang <fwang> 3.1.1-1.mga2
+ Revision: 211318
- new version 3.1.1

* Mon Feb 06 2012 fwang <fwang> 3.1.0-1.mga2
+ Revision: 205459
- new version 3.1.0

* Tue Dec 13 2011 fwang <fwang> 3.0.3-1.mga2
+ Revision: 181240
- new version 3.0.3

* Tue Oct 25 2011 fwang <fwang> 3.0.2-1.mga2
+ Revision: 157981
- new version 3.0.2

* Sat Oct 01 2011 wally <wally> 3.0.1-1.mga2
+ Revision: 150638
- new version 3.0.1

* Mon Sep 19 2011 wally <wally> 3.0.0-1.mga2
+ Revision: 145640
- new version 3.0.0
- clean .spec a bit

* Fri Sep 16 2011 fwang <fwang> 2.90.4-1.mga2
+ Revision: 144176
- fix linkage
- new version 2.90.4

* Thu Sep 01 2011 fwang <fwang> 2.90.3-1.mga2
+ Revision: 137427
- new version  2.90.3
- disable wrong script for checking req
- imported package python-gobject3
+ wally <wally>
- fix typo in python-gi-cairo provides/requires


* Sat Oct 30 2010 Olivier Thauvin <nanardon@mandriva.org> 2.26.0-2mdv2011.0
+ Revision: 590343
- rebuild for python

* Mon Sep 27 2010 Götz Waschk <waschk@mandriva.org> 2.26.0-1mdv2011.0
+ Revision: 581442
- new version
- update patch 2

* Fri Jul 30 2010 Götz Waschk <waschk@mandriva.org> 2.21.5-1mdv2011.0
+ Revision: 563398
- new version
- build with gobject-introspection

* Mon May 31 2010 Funda Wang <fwang@mandriva.org> 2.21.1-2mdv2010.1
+ Revision: 546766
- fix shared library linkage (mdv#59571)

* Sat Jan 02 2010 Götz Waschk <waschk@mandriva.org> 2.21.1-1mdv2010.1
+ Revision: 485574
- update to new version 2.21.1

* Fri Dec 18 2009 Götz Waschk <waschk@mandriva.org> 2.21.0-1mdv2010.1
+ Revision: 479908
- new version
- bump deps
- update file list

* Wed Sep 23 2009 Götz Waschk <waschk@mandriva.org> 2.20.0-1mdv2010.0
+ Revision: 448019
- update to new version 2.20.0

* Tue Aug 11 2009 Götz Waschk <waschk@mandriva.org> 2.19.0-1mdv2010.0
+ Revision: 415194
- new version
- update file list

* Wed Aug 05 2009 Götz Waschk <waschk@mandriva.org> 2.18.0-2mdv2010.0
+ Revision: 410191
- make fixxref executable
- move codegen files to devel package

* Mon May 25 2009 Götz Waschk <waschk@mandriva.org> 2.18.0-1mdv2010.0
+ Revision: 379436
- new version
- drop patch 1
- update file list

* Wed May 13 2009 Götz Waschk <waschk@mandriva.org> 2.17.0-3mdv2010.0
+ Revision: 375244
- fix devel deps

* Wed May 13 2009 Götz Waschk <waschk@mandriva.org> 2.17.0-2mdv2010.0
+ Revision: 375229
- make ffi dep private

* Mon May 11 2009 Götz Waschk <waschk@mandriva.org> 2.17.0-1mdv2010.0
+ Revision: 374166
- new version
- drop patch 1

* Mon Feb 23 2009 Götz Waschk <waschk@mandriva.org> 2.16.1-2mdv2009.1
+ Revision: 344032
- fix patch 0 (bug #48122)

* Sun Feb 22 2009 Götz Waschk <waschk@mandriva.org> 2.16.1-1mdv2009.1
+ Revision: 343818
- new version
- rediff patch 0

* Sun Jan 04 2009 Götz Waschk <waschk@mandriva.org> 2.16.0-1mdv2009.1
+ Revision: 324715
- update to new version 2.16.0

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 2.15.4-2mdv2009.1
+ Revision: 318414
- fix format error
- rebuild for new python

* Wed Sep 03 2008 Götz Waschk <waschk@mandriva.org> 2.15.4-1mdv2009.0
+ Revision: 279585
- new version

* Mon Sep 01 2008 Götz Waschk <waschk@mandriva.org> 2.15.3-3mdv2009.0
+ Revision: 278402
- fix dep on libffi (b.g.o bug #550231)

* Mon Sep 01 2008 Götz Waschk <waschk@mandriva.org> 2.15.3-2mdv2009.0
+ Revision: 278211
- build with libffi

* Mon Sep 01 2008 Götz Waschk <waschk@mandriva.org> 2.15.3-1mdv2009.0
+ Revision: 278072
- new version
- drop patch 1

* Mon Aug 04 2008 Götz Waschk <waschk@mandriva.org> 2.15.2-2mdv2009.0
+ Revision: 262917
- fix for bug 42467 (pygtk apps don't launch)

* Sun Jul 27 2008 Götz Waschk <waschk@mandriva.org> 2.15.2-1mdv2009.0
+ Revision: 250612
- new version
- add package for libpyglib
- disable --no-undefined

* Wed Jul 16 2008 Götz Waschk <waschk@mandriva.org> 2.15.1-1mdv2009.0
+ Revision: 236290
- new version
- update file list
- remove conflict with pygtk

* Tue Jul 15 2008 Götz Waschk <waschk@mandriva.org> 2.15.0-1mdv2009.0
+ Revision: 235854
- update license
- new version
- update file list
- add conflict with old pygtk2.0-devel
- update description

* Mon May 26 2008 Götz Waschk <waschk@mandriva.org> 2.14.2-1mdv2009.0
+ Revision: 211295
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - fix summary-not-capitalized

* Thu Jan 03 2008 Götz Waschk <waschk@mandriva.org> 2.14.1-1mdv2008.1
+ Revision: 142105
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Sep 20 2007 Olivier Blin <oblin@mandriva.com> 2.14.0-2mdv2008.0
+ Revision: 91462
- move development doc in devel package

* Sun Sep 16 2007 Götz Waschk <waschk@mandriva.org> 2.14.0-1mdv2008.0
+ Revision: 88449
- new version

* Sat Jul 07 2007 Götz Waschk <waschk@mandriva.org> 2.13.2-1mdv2008.0
+ Revision: 49435
- new version

* Thu Jun 28 2007 Helio Chissini de Castro <helio@mandriva.com> 2.13.1-3mdv2008.0
+ Revision: 45502
- MOve devel files for devel place

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 2.13.1-2mdv2008.0
+ Revision: 36193
- rebuild with correct optflags

  + Götz Waschk <waschk@mandriva.org>
    - new version


* Tue Nov 28 2006 Götz Waschk <waschk@mandriva.org> 2.12.3-2mdv2007.0
+ Revision: 87908
- rebuild

* Wed Nov 22 2006 Götz Waschk <waschk@mandriva.org> 2.12.3-1mdv2007.1
+ Revision: 86166
- new version
- unpack patch
- Import python-gobject

* Thu Oct 05 2006 Götz Waschk <waschk@mandriva.org> 2.12.2-1mdv2007.0
- New version 2.12.2

* Wed Sep 06 2006 Götz Waschk <waschk@mandriva.org> 2.12.1-1mdv2007.0
- New release 2.12.1

* Tue Aug 29 2006 Götz Waschk <waschk@mandriva.org> 2.11.4-1mdv2007.0
- New release 2.11.4

* Wed Aug 23 2006 Götz Waschk <waschk@mandriva.org> 2.11.3-1mdv2007.0
- New release 2.11.3

* Wed Aug 09 2006 Götz Waschk <waschk@mandriva.org> 2.11.2-1mdv2007.0
- New release 2.11.2

* Sun Aug 06 2006 Götz Waschk <waschk@mandriva.org> 2.11.1-1mdv2007.0
- update file list
- disable parallel make
- New release 2.11.1

* Fri Jul 14 2006 Götz Waschk <waschk@mandriva.org> 2.11.0-1mdv2007.0
- update the patch
- New release 2.11.0

* Wed Apr 12 2006 Götz Waschk <waschk@mandriva.org> 2.10.1-1mdk
- update patch
- New release 2.10.1

* Mon Mar 13 2006 Götz Waschk <waschk@mandriva.org> 2.10.0-1mdk
- New release 2.10.0

* Thu Feb 23 2006 Frederic Crozat <fcrozat@mandriva.com> 2.9.1-2mdk
- Allow compilation with old distro

* Tue Jan 17 2006 Götz Waschk <waschk@mandriva.org> 2.9.1-1mdk
- New release 2.9.1

* Wed Jan 11 2006 Michael Scherer <misc@mandriva.org> 2.9.0-3mdk
- Use new python macro

* Tue Jan 10 2006 Götz Waschk <waschk@mandriva.org> 2.9.0-2mdk
- add conflict to ease upgrade

* Tue Jan 10 2006 Götz Waschk <waschk@mandriva.org> 2.9.0-1mdk
- initial package

